@@ -3,12 +3,11 @@ from collections import defaultdict
 from enum import Enum
 from typing import Dict, List
 
+from dagster import Failure, MetadataEntry, RetryRequested
+from dagster.core.execution.context.compute import SolidExecutionContext
 from requests import Response
 from requests.exceptions import RequestException
 
-from dagster import EventMetadataEntry, Failure, RetryRequested
-from dagster.core.execution.context.compute import SolidExecutionContext
-
 
 def fmt_rpc_logs(logs: List[Dict]) -> Dict[int, str]:
     d = defaultdict(list)
@@ -41,51 +40,45 @@ def raise_for_rpc_error(context: SolidExecutionContext, resp: Response) -> None:
     error = resp.json().get("error")
     if error is not None:
         if error["code"] in [
-            DBTErrors.project_currently_compiling_error,
-            DBTErrors.runtime_error,
-            DBTErrors.server_error,
+            DBTErrors.project_currently_compiling_error.value,
+            DBTErrors.runtime_error.value,
+            DBTErrors.server_error.value,
         ]:
             context.log.warning(error["message"])
             raise RetryRequested(max_retries=5, seconds_to_wait=30)
-        elif error["code"] == DBTErrors.project_compile_failure_error:
+        elif error["code"] == DBTErrors.project_compile_failure_error.value:
             raise Failure(
                 description=error["message"],
                 metadata_entries=[
-                    EventMetadataEntry.text(text=str(error["code"]), label="RPC Error Code"),
-                    EventMetadataEntry.text(
+                    MetadataEntry.text(text=str(error["code"]), label="RPC Error Code"),
+                    MetadataEntry.text(
                         text=error["data"]["cause"]["message"], label="RPC Error Cause"
                     ),
                 ],
             )
-        elif error["code"] == DBTErrors.rpc_process_killed_error:
+        elif error["code"] == DBTErrors.rpc_process_killed_error.value:
             raise Failure(
                 description=error["message"],
                 metadata_entries=[
-                    EventMetadataEntry.text(text=str(error["code"]), label="RPC Error Code"),
-                    EventMetadataEntry.text(text=str(error["data"]["signum"]), label="RPC Signum"),
-                    EventMetadataEntry.text(
-                        text=error["data"]["message"], label="RPC Error Message"
-                    ),
+                    MetadataEntry.text(text=str(error["code"]), label="RPC Error Code"),
+                    MetadataEntry.text(text=str(error["data"]["signum"]), label="RPC Signum"),
+                    MetadataEntry.text(text=error["data"]["message"], label="RPC Error Message"),
                 ],
             )
-        elif error["code"] == DBTErrors.rpc_timeout_error:
+        elif error["code"] == DBTErrors.rpc_timeout_error.value:
             raise Failure(
                 description=error["message"],
                 metadata_entries=[
-                    EventMetadataEntry.text(text=str(error["code"]), label="RPC Error Code"),
-                    EventMetadataEntry.text(
-                        text=str(error["data"]["timeout"]), label="RPC Timeout"
-                    ),
-                    EventMetadataEntry.text(
-                        text=error["data"]["message"], label="RPC Error Message"
-                    ),
+                    MetadataEntry.text(text=str(error["code"]), label="RPC Error Code"),
+                    MetadataEntry.text(text=str(error["data"]["timeout"]), label="RPC Timeout"),
+                    MetadataEntry.text(text=error["data"]["message"], label="RPC Error Message"),
                 ],
             )
         else:
             raise Failure(
                 description=error["message"],
                 metadata_entries=[
-                    EventMetadataEntry.text(text=str(error["code"]), label="RPC Error Code"),
+                    MetadataEntry.text(text=str(error["code"]), label="RPC Error Code"),
                 ],
             )
 
